==> kubernetes-1.34.1.tar.gz: kubernetes-1.34.1/cmd/kube-controller-manager/app/networking.go <==
/*
Copyright 2023 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Package app implements a server that runs a set of active
// components.  This includes replication controllers, service endpoints and
// nodes.
package app

import (
	"context"

	"k8s.io/component-base/featuregate"
	"k8s.io/controller-manager/controller"
	"k8s.io/kubernetes/cmd/kube-controller-manager/names"
	"k8s.io/kubernetes/pkg/controller/servicecidrs"
	"k8s.io/kubernetes/pkg/features"
)

func newServiceCIDRsControllerDescriptor() *ControllerDescriptor {
	return &ControllerDescriptor{
		name:     names.ServiceCIDRController,
		initFunc: startServiceCIDRsController,
		requiredFeatureGates: []featuregate.Feature{
			features.MultiCIDRServiceAllocator,
		}}
}
func startServiceCIDRsController(ctx context.Context, controllerContext ControllerContext, controllerName string) (controller.Interface, bool, error) {
	go servicecidrs.NewController(
		ctx,
		controllerContext.InformerFactory.Networking().V1().ServiceCIDRs(),
		controllerContext.InformerFactory.Networking().V1().IPAddresses(),
		controllerContext.ClientBuilder.ClientOrDie("service-cidrs-controller"),
	).Run(ctx, 5)
	// TODO use component config
	return nil, true, nil

}

==> kubernetes-1.35.0.tar.gz: kubernetes-1.35.0/cmd/kube-controller-manager/app/networking.go <==
/*
Copyright 2023 The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Package app implements a server that runs a set of active
// components.  This includes replication controllers, service endpoints and
// nodes.
package app

import (
	"context"

	"k8s.io/component-base/featuregate"
	"k8s.io/kubernetes/cmd/kube-controller-manager/names"
	"k8s.io/kubernetes/pkg/controller/servicecidrs"
	"k8s.io/kubernetes/pkg/features"
)

func newServiceCIDRsControllerDescriptor() *ControllerDescriptor {
	return &ControllerDescriptor{
		name:        names.ServiceCIDRController,
		constructor: newServiceCIDRsController,
		requiredFeatureGates: []featuregate.Feature{
			features.MultiCIDRServiceAllocator,
		},
	}
}

func newServiceCIDRsController(ctx context.Context, controllerContext ControllerContext, controllerName string) (Controller, error) {
	client, err := controllerContext.NewClient("service-cidrs-controller")
	if err != nil {
		return nil, err
	}

	// TODO use component config
	scc := servicecidrs.NewController(
		ctx,
		controllerContext.InformerFactory.Networking().V1().ServiceCIDRs(),
		controllerContext.InformerFactory.Networking().V1().IPAddresses(),
		client,
	)
	return newControllerLoop(func(ctx context.Context) {
		scc.Run(ctx, 5)
	}, controllerName), nil
}
